==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/BollingerBandWidthIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { BollingerBandWidthIndicatorDescription } from "./BollingerBandWidthIndicatorDescription";
/**
 * @hidden
 */
var BollingerBandWidthIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BollingerBandWidthIndicatorDescriptionMetadata, _super);
    function BollingerBandWidthIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandWidthIndicatorDescriptionMetadata.b = function (a) {
        if (BollingerBandWidthIndicatorDescriptionMetadata.a == null) {
            BollingerBandWidthIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BollingerBandWidthIndicatorDescriptionMetadata.c(BollingerBandWidthIndicatorDescriptionMetadata.a);
        }
        if (a.j(BollingerBandWidthIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(BollingerBandWidthIndicatorDescriptionMetadata.a);
    };
    BollingerBandWidthIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
        a.item("Multiplier", "Number:double");
    };
    BollingerBandWidthIndicatorDescriptionMetadata.d = function (a) {
        BollingerBandWidthIndicatorDescriptionMetadata.b(a);
        a.aa("BollingerBandWidthIndicator", function () { return new BollingerBandWidthIndicatorDescription(); });
        a.z("BollingerBandWidthIndicator", BollingerBandWidthIndicatorDescriptionMetadata.a);
    };
    BollingerBandWidthIndicatorDescriptionMetadata.$t = markType(BollingerBandWidthIndicatorDescriptionMetadata, 'BollingerBandWidthIndicatorDescriptionMetadata');
    BollingerBandWidthIndicatorDescriptionMetadata.a = null;
    return BollingerBandWidthIndicatorDescriptionMetadata;
}(Base));
export { BollingerBandWidthIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/BollingerBandWidthIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { BollingerBandWidthIndicatorDescription } from "./BollingerBandWidthIndicatorDescription";
/**
 * @hidden
 */
var BollingerBandWidthIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(BollingerBandWidthIndicatorDescriptionMetadata, _super);
    function BollingerBandWidthIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    BollingerBandWidthIndicatorDescriptionMetadata.b = function (a) {
        if (BollingerBandWidthIndicatorDescriptionMetadata.a == null) {
            BollingerBandWidthIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            BollingerBandWidthIndicatorDescriptionMetadata.c(BollingerBandWidthIndicatorDescriptionMetadata.a);
        }
        if (a.k(BollingerBandWidthIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(BollingerBandWidthIndicatorDescriptionMetadata.a);
    };
    BollingerBandWidthIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
        a.item("Multiplier", "Number:double");
    };
    BollingerBandWidthIndicatorDescriptionMetadata.d = function (a) {
        BollingerBandWidthIndicatorDescriptionMetadata.b(a);
        a.ac("BollingerBandWidthIndicator", function () { return new BollingerBandWidthIndicatorDescription(); });
        a.ab("BollingerBandWidthIndicator", BollingerBandWidthIndicatorDescriptionMetadata.a);
    };
    BollingerBandWidthIndicatorDescriptionMetadata.$t = markType(BollingerBandWidthIndicatorDescriptionMetadata, 'BollingerBandWidthIndicatorDescriptionMetadata');
    BollingerBandWidthIndicatorDescriptionMetadata.a = null;
    return BollingerBandWidthIndicatorDescriptionMetadata;
}(Base));
export { BollingerBandWidthIndicatorDescriptionMetadata };
